@@ -10,8 +10,9 @@ use strict;
 
 use Hub qw/:lib/;
 
-our ($VERSION,$AUTOLOAD);
+our ($AUTOLOAD);
 
+our $VERSION        = '3.01048';
 our @EXPORT         = qw//;
 our @EXPORT_OK      = qw//;
 
@@ -47,5 +48,4 @@ sub DESTROY {
 }#DESTROY
 
 
-
 '???';
